!-------------------------------------BOF---------------------------------------

      Subroutine VUAMP(
!       read only
     *  ampName,            ! amplitude name
     *  time,               ! array with time
     *  ampValueOld,        ! amplitude value from previous inc.
     *  dt,                 ! time step for current inc.
     *  nprops,             ! properties array size
     *  props,              ! properties array
     *  nSvars,             ! state-dep. array size
     *  svars,              ! state-dep. array
     *  lFlagsInfo,         ! flag array with information
     *  nSensor,            ! number of sensors in the model
     *  sensorValues,       ! sensor values array
     *  sensorNames,        ! sensor names array
     *  jSensorLookUpTable, ! internal variable
!       write only
     *  ampValueNew,        ! amplitude value
!       write only (optional)
     *  lFlagsDefine,
     *  AmpDerivative,      ! Current value of the amplitude derivative
     *  AmpSecDerivative,   ! Current value of the amplitude second derivative
     *  AmpIncIntegral)     ! Current value of the amplitude incremental integral

      include 'vaba_param.inc'

!     time indices
      parameter (iStepTime        = 1,
     *           iTotalTime       = 2,
     *           nTime            = 2)
!     flags passed in for information
      parameter (iInitialization   = 1,
     *           iRegularInc       = 2,
     *           ikStep            = 3,
     *           nFlagsInfo        = 3)
!     optional flags to be defined
      parameter (iComputeDeriv     = 1,
     *           iComputeSecDeriv  = 2,
     *           iComputeInteg     = 3,
     *           iStopAnalysis     = 4,
     *           iConcludeStep     = 5,
     *           nFlagsDefine      = 5)
      dimension time(nTime), lFlagsInfo(nFlagsInfo),
     *          lFlagsDefine(nFlagsDefine),
     *          sensorValues(nSensor),
     *          props(nprops),
     *          sVars(nSvars)

      character*80 sensorNames(nSensor)
      character*80 ampName
      dimension jSensorLookUpTable(*)

!-------------------------------------------------------------------------------
!     START -> Source code
!-------------------------------------------------------------------------------

!----6----------------------------------------------------------------72--------

      if (lFlagsInfo(iInitialization) == 1) then

        ampValueNew = 0.d0
        ampValueOld = 0.d0

      else

!       --------------------------------------------------------------72--------
!       block for first user amplitude
        if (ampName == "X-MOVE-VUAMP") then

          ! read props
          rOmega  = props(1)
          rRadius = props(2)

          ! calc x-dir velocity
          rVel = -rRadius*rOmega*sin(rOmega*time(iTotalTime))
          ! calc displacement (xDisp = vel * dt)
          rDisp = rVel * dt
          ! update amplitude value (old disp + new disp)
          ampValueNew = ampValueOld + rDisp

!       --------------------------------------------------------------72--------
!       block for second user amplitude
        else if (ampName == "Y-MOVE-VUAMP") then

          ! read props
          rOmega  = props(1)
          rRadius = props(2)

          ! calc y-dir velocity
          rVel = rRadius*rOmega*cos(rOmega*time(iTotalTime))
          ! calc displacement (yDisp = vel * dt)
          rDisp = rVel * dt
          ! update amplitude value (old disp + new disp)
          ampValueNew = ampValueOld + rDisp

        end if

      end if

!----6----------------------------------------------------------------72--------

!-------------------------------------------------------------------------------
!     END -> Source code
!-------------------------------------------------------------------------------

      return
      end subroutine VUAMP

!-------------------------------------EOF---------------------------------------
